-------------------------------------------------------------------------------
-- Some nice localization to make those other people in the world feel right
--  at home too.
-------------------------------------------------------------------------------

local _, Me = ...

-------------------------------------------------------------------------------
-- First of all, we have this table filled with localization strings.
-- In bigger projects, this can get quite massive. We don't have that many
-- strings, but we'll still use some decent practices so we don't have a bunch 
-- of stuff lying around in memory;
local Locales = {} -- For example, we'll delete this big table after 
Locales.enUS = {
	-- The addon title.
	CROSS_RP = "Cross RP";
	-- The tooltip text for Cross RP in the game's addon selection menu.
	ADDON_NOTES = "Links friends for cross-faction roleplay!";
	
	-- Menu button in the main minimap menu to open the channel selection tab.
	RP_CHANNELS = "RP Channels";
	-- Tooltip for the menu button in the main minimap menu to open the channel selection tab.
	RP_CHANNELS_TOOLTIP = "Select which /rp channels to show in your chatboxes.";
	-- A notice that shows in the minimap menu when the RP channel is muted.
	RP_IS_MUTED = "RP Is Muted";
	-- Additional information about the mute function, tooltip for the RP IS MUTED label.
	RP_IS_MUTED_TOOLTIP = "When RP is muted, normal community members cannot post in /rp. They can still post in /rp2-9.";
	-- The button that opens the Cross RP Interface options in the minimap menu.
	SETTINGS = "Settings";
	-- Tooltip for the Settings button in the minimap button menu.
	SETTINGS_TIP = "Open Interface options panel.";
	-- Tooltip for when mousing over a server in the minimap menu server list.
	CONNECT_TO_SERVER_TOOLTIP = "Click to connect.";
	-- Name of the RP Warning channel (/rpw).
	RP_WARNING = "RP Warning";
	-- Tooltip for the RP Warning channel in the minimap menu and options.
	RP_WARNING_TOOLTIP = "Similar to raid warning, this is accessed by leaders only with /rpw.";
	-- Title of the global RP channel (/rp). Used in a number of places in the options.
	RP_CHANNEL = "RP Channel";
	-- Title for the secondary RP channels (/rp#), used in the options. {1} is a number 2-9.
	RP_CHANNEL_X = "RP Channel {1}";
	-- Tooltip for toggling the RP channel in the minimap menu. Also shows up in the options panel when mousing over the color option for it.
	RP_CHANNEL_1_TOOLTIP = "The main RP channel. Access through /rp.";
	-- Tooltip for toggling the secondary RP channels in the minimap menu. Also shows up in the options panel when mousing over the color option for them. {1} is a number 2-9.
	RP_CHANNEL_X_TOOLTIP = "Channels 2-9 are meant for smaller sub-groups. Access through /rp#.";
	VERSION_LABEL = "Version: {1}";
	-- The author tag in the options panel.
	BY_AUTHOR = "by Tammya-MoonGuard";
	-- Label for the option that toggles the minimap menu button visibility.
	OPTION_MINIMAP_BUTTON = "Show Minimap Button";
	-- Tooltiop for the option that toggles the minimap menu button visibility.
	OPTION_MINIMAP_BUTTON_TIP = "Show or hide the minimap button (if you're using something else like Titan Panel to access it).";
	-- Label for the option that toggles the chat bubble modifications.
	OPTION_TRANSLATE_CHAT_BUBBLES = "Translate Chat Bubbles";
	-- Tooltip for the option that toggles the chat bubble modifications.
	OPTION_TRANSLATE_CHAT_BUBBLES_TIP = "Try and translate chat bubbles alongside text.";
	-- Label for the option that toggles the "Whisper" button when right-clicking an enemy player.
	OPTION_WHISPER_BUTTON = "Whisper Button";
	-- Tooltip for the option that toggles the "Whisper" button when right-clicking an enemy player.
	OPTION_WHISPER_BUTTON_TIP = "Adds a \"Whisper\" button when right-clicking on players from opposing faction if they're Battle.net friends. This may or may not break some things in the Blizzard UI, and you don't need it to /w someone cross-faction.";
	-- Label for the chat colors section in the options panel.
	OPTION_CHAT_COLORS = "Chat Colors";
	
	-- A notice printed to chat when a user tries to use the /rpw command without permission.
	CANT_POST_RPW2 = "Only group leaders or assistants can post in RP Warning.";
	WHISPER = "Whisper";
	WHISPER_TIP = "Whisper opposing faction. (This is sent safely over a direct Battle.net whisper, privately, and doesn't use the community relay.)";
	-- The label for the traffic monitor in the minimap button tooltip while connected.
	TRAFFIC = "Traffic";
	-- For the traffic monitor, suffix for kilobytes per second.
	KBPS = "KB/s";
	-- Shown in the traffic monitor, for bytes per second. e.g. "Traffic: 520 B/s"
	BPS = "B/s";
	-- What's shown when a community's name cannot be resolved for some reason. Probably won't ever be used.
	UNKNOWN_SERVER = "(Unknown)";
	
	-- Help text in the minimap button tooltip.
	MINIMAP_TOOLTIP_CLICK_OPEN_MENU = "|cffddddddClick to open menu.";
	-- Help text in the minimap button tooltip.
	MINIMAP_TOOLTIP_RIGHTCLICK_OPEN_MENU = "|cffddddddRight-click to open menu.";
	
	-- How the client should localize height numbers. Can be "FEETINCHES" or "CM".
	HEIGHT_UNIT = "FEETINCHES";
	WEIGHT_UNIT = "POUNDS";
	-- Label for the toggle switch in the world map tracking list. This toggles showing Cross RP players on the map.
	MAP_TRACKING_CROSSRP_PLAYERS = "Cross RP Players";
	
	---------------------------------------------------------------------------------------
	-- The API can't fetch these for us for languages we don't know. These need
	--  to be filled in for each locale. In the future we might add more fake
	--            languages that can have their own IDs for extra RP languages.
	---------------------------------------------------------------------------------------

	-- This needs to match EXACTLY the ingame name for the language Orcish. Cross RP uses it to detect that language.
	LANGUAGE_1 = "Orcish";
	-- This needs to match EXACTLY the ingame name for the language Common. Cross RP uses it to detect that language.
	LANGUAGE_7 = "Common";
	LANGUAGES_NOT_SET = "Language names have not been set up for your locale. Cross RP may not function properly.";
	
	-- Unused. Used to be the label for showing how long the relay has been idle in the minimap button tooltip.
	IDLE_TIME = "Idle Time";
	UPTIME = "Uptime";
	
	VERSION_TOO_OLD = "A required update is available and your current version may not work properly. Please download the latest release of Cross RP at your nearest convenience.";
	-- A message that tells the user what the latest version is. {1} is replaced with a version string such as "2.0.0".
	LATEST_VERSION = "Latest release version is {1}.";
	
	-- Currently unused. Label for the Links button in the minimap menu (opens up a list of Cross RP community links).
	LINKS = "Links";
	-- (Unused) Tooltip for the Links button in the minimap menu.
	LINKS_TOOLTIP = "Easy access to Cross RP hosted communities.";
	-- Shown when the user is missing core files and needs to restart their game (or something else is wrong, which is unlikely).
	UPDATE_ERROR = "Cross RP is not installed correctly. If you recently updated, please close the game and restart it completely. If this error persists and you are using the latest version of Cross RP, please submit an issue report.";
	
	-- This is a notice that pops up when your Elixir of Tongues is running out. {1} is formatted as a time like "48 seconds" (seconds/minutes is localized elsewhere).
	ELIXIR_NOTICE = "Elixir of Tongues expires in {1}.";
	-- When the timer for the elixir notice reaches 0, this is shown instead.
	ELIXIR_NOTICE_EXPIRED = "Elixir of Tongues has expired.";
	
	-- This shows up in the minimap tooltip, when Cross RP is "active" (meaning you are actively engaging in cross-faction RP).
	CROSSRP_ACTIVE = "Active";
	-- This shows up in the minimap tooltip, when Cross RP is "idle", meaning it's in a low-power standby mode until you find some cross-faction RP.
	CROSSRP_INACTIVE = "Idle";
	
	-- Label for the "Translate Emotes" button in the minimap button menu.
	TRANSLATE_EMOTES = "Translate Emotes";
	-- Tooltip text for the Translate Emotes button.
	TRANSLATE_EMOTES_TIP = "Turn /emote text into /say text when near the opposite faction. The other side doesn't need Cross RP installed.\n\nThis doesn't have any effect if Cross RP is Idle (red icon).\n\nAvoid getting drunk.";
	
	-- Label for the network status in the minimap button tooltip.
	NETWORK_STATUS = "Network Status";
	-- Label for the network status display when you don't have any connections to other realms or factions.
	NO_CONNECTIONS = "No connections.";
	
	-- Error printed when you try to use /rp chat while not in a linked group.
	NOT_IN_LINKED_GROUP = "You're not in a linked group.";
	
	USER_CONNECTED_TO_YOUR_GROUP = "{1} has connected to your group.";
	-- Label for the button in the minimap menu to start a linked group.
	LINK_GROUP = "Link Group";
	-- Label for the button in the minimap button menu to stop the group from being linked. Only usable by party leaders.
	UNLINK_GROUP = "Unlink Group";
	-- A message printed to chat when the party leader starts a linked group.
	GROUP_LINKED = "You have joined a linked group.";
	-- This prints to chat when the party leader stops the group from being linked.
	GROUP_UNLINKED = "Your group is no longer linked.";
	-- This is shown in the tooltip for the Link Group button to let the user know they can't change this unless they're the party leader.
	NEEDS_GROUP_LEADER = "Only group leaders can change this.";
	-- Error message when the user presses the Link/Unlink Group button when they aren't the party leader. Similar to the previous translation, but English uses "that" instead of "this" because the chatbox is usually far away from the minimap menu. :)
	NEEDS_GROUP_LEADER2 = "Only group leaders can change that.";
	
	-- This shows up in the minimap tooltip; it's a status label that lets the user know they're in a linked group.
	GROUP_STATUS_LINKED = "Group Linked";
	
	-- Tooltip for the Link Group button in the minimap menu.
	LINK_GROUP_TOOLTIP = "You can link your group to other groups with this, and /rp chat is used to talk between them.";
	-- Tooltip text for the Unlink Group button in the minimap menu.
	UNLINK_GROUP_TOOLTIP = "Unlink your group from others, disabling /rp chat.";
	
	-- This is an error message that shows up in chat when you try to use a Cross RP feature, but you need to wait until Cross RP is done initializing.
	CROSSRP_NOT_DONE_INITIALIZING = "Cross RP hasn't finished starting up yet.";
	
	-- Help text for the dialog that pops up when the user clicks Link Group.
	LINK_GROUP_DIALOG = "Enter a password for your linked group. Groups using the same password will be linked.";
	-- Error printed to chat when your RP chat message fails due to network problems.
	RPCHAT_TIMED_OUT = "Message to {1} timed out.";
	-- Error that's printed to chat when your RP chat message failed due to having no bridge. A bridge is a player on your realm and faction that can deliver your message to another realm or faction (through their Battle.net friends).
	RPCHAT_NOBRIDGE = "Couldn't send message to {1}. No bridge available.";
	RELAY_RP_CHAT = "Relay RP Chat";
	RELAY_RP_CHAT_TOOLTIP = "For group leaders only: any RP chat received will be copied into /raid or /party for users without Cross RP to see.";
	
	RELAY_RP_ROLL = "[{1}] rolled {2} ({3}-{4})";
	
	-- Error message that's shown when you try to refresh your Elixir of Tongues, but don't have any.
	NO_MORE_ELIXIRS = "You're out of elixirs!";
	
	INVALID_FACTION = "Disabling due to not having a faction selected.";
};
Locales.deDE = {
	["BPS"] = "B/s",
	["BY_AUTHOR"] = "von Tammya-MoonGuard, übersetzt von Vorathel-ArgentDawn",
	["CONNECT_TO_SERVER_TOOLTIP"] = "Klicken zum verbinden.",
	["CROSS_RP"] = "Cross RP",
	["HEIGHT_UNIT"] = "CM",
	["KBPS"] = "KB/s",
	["LANGUAGE_1"] = "Orcisch",
	["LANGUAGE_7"] = "Gemeinsprache",
	["LANGUAGES_NOT_SET"] = "Sprachnamen wurden noch nicht für deine Lokalisierung eingerichtet. Cross RP funktioniert möglicherweise nicht richtig.",
	["MAP_TRACKING_CROSSRP_PLAYERS"] = "Cross RP Spieler",
	["OPTION_CHAT_COLORS"] = "Chat Farben",
	["OPTION_MINIMAP_BUTTON"] = "Minimap Schaltfläche anzeigen",
	["OPTION_MINIMAP_BUTTON_TIP"] = "Zeigt oder versteckt die Minimap Schaltfläche (falls du soetwas wie Titan Panel benutzt um darauf zuzugreifen).",
	["OPTION_TRANSLATE_CHAT_BUBBLES"] = "Übersetze Sprechblasen",
	["OPTION_TRANSLATE_CHAT_BUBBLES_TIP"] = "Es wird versucht den Text im Chatverlauf und dazugehörige Sprechblasen zu übersetzen.",
	["OPTION_WHISPER_BUTTON"] = "Flüstern Schaltfläche",
	["OPTION_WHISPER_BUTTON_TIP"] = "Fügt eine \"Flüstern\" Schaltfläche beim rechtsklicken eines Spielers der anderen Fraktion hinzu sofern dieser ein battle.net Freund ist. Dies könnte möglischerweise zu Problemen mit der Blizzard UI führen, aber du brauchst sie nicht um einen Spieler der anderen Fraktion zu flüstern.",
	["RP_CHANNEL"] = "RP Kanal",
	["RP_CHANNEL_1_TOOLTIP"] = "Der Haupt RP Kanal. Zugriff über /rp.",
	["RP_CHANNEL_X"] = "RP Kanal {1}",
	["RP_CHANNEL_X_TOOLTIP"] = "Die Kanäle 2-9 sind für Untergruppen gedacht. Zugriff über /rp#.",
	["RP_CHANNELS"] = "RP Kanäle",
	["RP_CHANNELS_TOOLTIP"] = "Wähle aus welchem Kanal du in deiner Chatbox lesen möchtest.",
	["RP_IS_MUTED"] = "RP ist stumm gestellt",
	["RP_IS_MUTED_TOOLTIP"] = "Wenn RP stumm ist dann können normale Community Mitglieder nicht in /rp schreiben. Sie können aber immernoch in /rp2-9 schreiben.",
	["RP_WARNING"] = "RP Warnung",
	["RP_WARNING_TOOLTIP"] = "Ähnlich wie eine Schlachtzugswarnung ist diese für Moderatoren verfügbar über /rpw.",
	["SETTINGS"] = "Einstellungen",
	["SETTINGS_TIP"] = "Öffne das Interface Optionsmenü.",
	["TRAFFIC"] = "Traffic",
	["UNKNOWN_SERVER"] = "(Unbekannt)",
	["VERSION_LABEL"] = "Version: {1}",
	["WEIGHT_UNIT"] = "KG",
	["WHISPER"] = "Flüstern",
	["WHISPER_TIP"] = "Flüster zur gegnerischen Fraktion. (Dies ist sicher und direkt über Battle.net übertragen und deshalb privat, was bedeutet das es nicht die Community Übertragung benutzt.)"
}

Locales.esES = {
	["BPS"] = "B/s",
	["BY_AUTHOR"] = "por Tammya-MoonGuard, traducido por Ynaar-ArgentDawn",
	["CONNECT_TO_SERVER_TOOLTIP"] = "Pulsar para conectar",
	["CROSS_RP"] = "Cross RP",
	["HEIGHT_UNIT"] = "CM",
	["KBPS"] = "KB/s",
	["LANGUAGE_1"] = "Orco",
	["LANGUAGE_7"] = "Lengua común",
	["LANGUAGES_NOT_SET"] = "Los idiomas no han sido editados para tu locale, Cross RP puede fallar.",
	["MAP_TRACKING_CROSSRP_PLAYERS"] = "Usuarios de Cross RP",
	["OPTION_CHAT_COLORS"] = "Colores de chat",
	["OPTION_MINIMAP_BUTTON"] = "Mostrar botón de minimapa",
	["OPTION_MINIMAP_BUTTON_TIP"] = "Mostrar o esconder el botón del minimapa (Si usas algo diferente que Titan Panel para accederlo).",
	["OPTION_TRANSLATE_CHAT_BUBBLES"] = "Traducir burbujas de chat",
	["OPTION_TRANSLATE_CHAT_BUBBLES_TIP"] = "Intenta traducir las burbujas de chat junto al chat.",
	["OPTION_WHISPER_BUTTON"] = "Botón de susurro",
	["OPTION_WHISPER_BUTTON_TIP"] = "Añade un botón de \"Susurro\" Cuando pulsas botón derecho en judagores de la facción opuesta si son amigos por Battle.net. Esto quizas rompa algunos elementos de la Interfaz de Blizzard, y no es necesario para enviar susurros entre facciones.",
	["RP_CHANNEL"] = "Canal de RP",
	["RP_CHANNEL_1_TOOLTIP"] = "El canal de RP global para los miembros del servidor. Accede usando /rp.",
	["RP_CHANNEL_X"] = "Canal de RP {1}",
	["RP_CHANNEL_X_TOOLTIP"] = "Los canales 2-9 son pensados para grupos mas pequeños, accede usando /rp#.",
	["RP_CHANNELS"] = "Canales de RP",
	["RP_CHANNELS_TOOLTIP"] = "Selecciona que canales de RP quieres escuchar en tu chat.",
	["RP_IS_MUTED"] = "RP está silenciado",
	["RP_IS_MUTED_TOOLTIP"] = "Cuando RP está silenciado, miembros de la comunidad no pueden enviar mensajes por /rp. No les impide enviar mensajes por /rp2-9.",
	["RP_WARNING"] = "Alerta de RP",
	["RP_WARNING_TOOLTIP"] = "Similar a Alerta de Banda, solo puede ser accedido por líderes de comunidad usando /rpw.",
	["SETTINGS"] = "Opciones",
	["SETTINGS_TIP"] = "Abre el panel de opciones de interfaz.",
	["TRAFFIC"] = "Tráfico",
	["UNKNOWN_SERVER"] = "(Desconocido)",
	["VERSION_LABEL"] = "Versión: {1}",
	["WEIGHT_UNIT"] = "KG",
	["WHISPER"] = "Susurro",
	["WHISPER_TIP"] = "Susurra a la facción opuesta (El mensaje es enviado de forma segura por un susurro de battle.net, de forma privada, y no usa el relé de la comunidad)."
}

Locales.esMX = {
	["BPS"] = "B/s",
	["BY_AUTHOR"] = "por Tammya-MoonGuard, traducido por Ynaar-ArgentDawn",
	["CONNECT_TO_SERVER_TOOLTIP"] = "Pulsar para conectar",
	["CROSS_RP"] = "Cross RP",
	["HEIGHT_UNIT"] = "CM",
	["KBPS"] = "KB/s",
	["LANGUAGE_1"] = "Orco",
	["LANGUAGE_7"] = "Lengua común",
	["LANGUAGES_NOT_SET"] = "Los idiomas no han sido editados para tu locale, Cross RP puede fallar.",
	["MAP_TRACKING_CROSSRP_PLAYERS"] = "Usuarios de Cross RP",
	["OPTION_CHAT_COLORS"] = "Colores de chat",
	["OPTION_MINIMAP_BUTTON"] = "Mostrar botón de minimapa",
	["OPTION_MINIMAP_BUTTON_TIP"] = "Mostrar o esconder el botón del minimapa (Si usas algo diferente que Titan Panel para accederlo).",
	["OPTION_TRANSLATE_CHAT_BUBBLES"] = "Traducir burbujas de chat",
	["OPTION_TRANSLATE_CHAT_BUBBLES_TIP"] = "Intenta traducir las burbujas de chat junto al chat.",
	["OPTION_WHISPER_BUTTON"] = "Botón de susurro",
	["OPTION_WHISPER_BUTTON_TIP"] = "Añade un botón de \"Susurro\" Cuando pulsas botón derecho en judagores de la facción opuesta si son amigos por Battle.net. Esto quizas rompa algunos elementos de la Interfaz de Blizzard, y no es necesario para enviar susurros entre facciones.",
	["RP_CHANNEL"] = "Canal de RP",
	["RP_CHANNEL_1_TOOLTIP"] = "El canal de RP global para los miembros del servidor. Accede usando /rp.",
	["RP_CHANNEL_X"] = "Canal de RP {1}",
	["RP_CHANNEL_X_TOOLTIP"] = "Los canales 2-9 son pensados para grupos mas pequeños, accede usando /rp#.",
	["RP_CHANNELS"] = "Canales de RP",
	["RP_CHANNELS_TOOLTIP"] = "Selecciona que canales de RP quieres escuchar en tu chat.",
	["RP_IS_MUTED"] = "RP está silenciado",
	["RP_IS_MUTED_TOOLTIP"] = "Cuando RP está silenciado, miembros de la comunidad no pueden enviar mensajes por /rp. No les impide enviar mensajes por /rp2-9.",
	["RP_WARNING"] = "Alerta de RP",
	["RP_WARNING_TOOLTIP"] = "Similar a Alerta de Banda, solo puede ser accedido por líderes de comunidad usando /rpw.",
	["SETTINGS"] = "Opciones",
	["SETTINGS_TIP"] = "Abre el panel de opciones de interfaz.",
	["TRAFFIC"] = "Tráfico",
	["UNKNOWN_SERVER"] = "(Desconocido)",
	["VERSION_LABEL"] = "Versión: {1}",
	["WEIGHT_UNIT"] = "KG",
	["WHISPER"] = "Susurro",
	["WHISPER_TIP"] = "Susurra a la facción opuesta (El mensaje es enviado de forma segura por un susurro de battle.net, de forma privada, y no usa el relé de la comunidad)."
}

Locales.frFR = {
	["BPS"] = "o/s",
	["BY_AUTHOR"] = "par Tammya-MoonGuard",
	["CONNECT_TO_SERVER_TOOLTIP"] = "Cliquez pour vous connecter.",
	["CROSS_RP"] = "Cross RP",
	["HEIGHT_UNIT"] = "CM",
	["KBPS"] = "Ko/s",
	["LANGUAGE_1"] = "Orc",
	["LANGUAGE_7"] = "Commun",
	["LANGUAGES_NOT_SET"] = "Les Langues n'ont pas été paramétrés pour votre région. Toutes les fonctionnalités de Cross RP peuvent ne pas être actives.",
	["MAP_TRACKING_CROSSRP_PLAYERS"] = "Joueurs Cross RP",
	["OPTION_CHAT_COLORS"] = "Couleurs de discussion",
	["OPTION_MINIMAP_BUTTON"] = "Afficher le bouton de la minicarte",
	["OPTION_MINIMAP_BUTTON_TIP"] = "Affiche ou cache le bouton de la minicarte (si vous utilisez quelque chose d'autre comme Titan Panel pour y accéder).",
	["OPTION_TRANSLATE_CHAT_BUBBLES"] = "Traduire les bulles de dialogue",
	["OPTION_TRANSLATE_CHAT_BUBBLES_TIP"] = "Essaie de traduire les bulles de dialogue en plus du texte.",
	["OPTION_WHISPER_BUTTON"] = "Bouton de chuchotement",
	["OPTION_WHISPER_BUTTON_TIP"] = "Ajoute un bouton \"Chuchoter\" lorsque vous faites un clic droit sur un joueur de la faction adverse s'il est ami Battle.net avec vous. Ceci peut ou non casser certaines fonctions de l'interface Blizzard, et vous n'en avez pas besoin pour /w quelqu'un dans la faction adverse.",
	["RP_CHANNEL"] = "Canal RP",
	["RP_CHANNEL_1_TOOLTIP"] = "Le canal RP global pour cette communauté. Peut être limité à des annonces uniquement. Accédez-y en tapant /rp.",
	["RP_CHANNEL_X"] = "Canal RP {1}",
	["RP_CHANNEL_X_TOOLTIP"] = "Les canaux 2-9 sont dédiés à des sous-groupes plus petits. Accédez-y en tapant /rp#.",
	["RP_CHANNELS"] = "Canaux RP",
	["RP_CHANNELS_TOOLTIP"] = "Sélectionnez quels canaux RP vous souhaitez afficher dans vos fenêtres de discussion.",
	["RP_IS_MUTED"] = "RP est verrouillé",
	["RP_IS_MUTED_TOOLTIP"] = "Lorsque RP est verrouillé, les membres de communauté normaux ne peuvent pas poster dans /rp. Ils peuvent toujours poster dans /rp2-9.",
	["RP_WARNING"] = "Alerte RP",
	["RP_WARNING_TOOLTIP"] = "Le canal d'alerte global. Il n'est accessible qu'aux responsables de la communauté en tapant /rpw.",
	["SETTINGS"] = "Paramètres",
	["SETTINGS_TIP"] = "Ouvre le panneau d'options d'interface.",
	["TRAFFIC"] = "Trafic",
	["UNKNOWN_SERVER"] = "(Inconnu)",
	["VERSION_LABEL"] = "Version: {1}",
	["WEIGHT_UNIT"] = "KG",
	["WHISPER"] = "Chuchoter",
	["WHISPER_TIP"] = "Chuchote à la faction adverse. (Ceci est envoyé de manière sécurisée via un chuchotement Battle.net direct, privé, et n'utilise pas le relai de communauté.)"
}

Locales.itIT = {
	["LANGUAGE_1"] = "Orchesco",
	["LANGUAGE_7"] = "Comune"
}

Locales.koKR = {
}

Locales.ptBR = {
	["BPS"] = "B/s",
	["BY_AUTHOR"] = "por Tammya-MoonGuard, traduzido por Belythalin-ArgentDawn",
	["CONNECT_TO_SERVER_TOOLTIP"] = "Clique para se conectar",
	["CROSS_RP"] = "Cross RP",
	["HEIGHT_UNIT"] = "CM",
	["KBPS"] = "KB/s",
	["LANGUAGE_1"] = "Órquico",
	["LANGUAGE_7"] = "Língua Comum",
	["LANGUAGES_NOT_SET"] = "Os nomes das linguagens não foram estabelecidos para a sua localização. O Cross RP pode não funcionar corretamente.",
	["MAP_TRACKING_CROSSRP_PLAYERS"] = "Jogadores com Cross RP",
	["OPTION_CHAT_COLORS"] = "Cores do Chat",
	["OPTION_MINIMAP_BUTTON"] = "Mostrar o Botão no Minimapa",
	["OPTION_MINIMAP_BUTTON_TIP"] = "Mostrar ou esconder o botão no minimapa (se estiver  a usar algo como Titan Panel para o acessar).",
	["OPTION_TRANSLATE_CHAT_BUBBLES"] = "Traduzir os Balões de Diálogo. ",
	["OPTION_TRANSLATE_CHAT_BUBBLES_TIP"] = "Tenta traduzir os balões de diálogo juntamente com o texto.",
	["OPTION_WHISPER_BUTTON"] = "Botão Sussurro",
	["OPTION_WHISPER_BUTTON_TIP"] = "Adiciona um botão \"Sussurro\" quando clica com o rato direito num jogador da facção oposta se for seu amigo no Battle.net. Tal pode ou não quebrar algumas funcionalidades da UI da Blizzard e não é necessário para /w alguém entre facções.",
	["RP_CHANNEL"] = "Canal RP",
	["RP_CHANNEL_1_TOOLTIP"] = "O principal canal RP. Acesse através de /rp.",
	["RP_CHANNEL_X"] = "Canal RP {1}",
	["RP_CHANNEL_X_TOOLTIP"] = "Canais 2-9 são pretendidos para pequenos sub-grupos. Acesse através de /rp#. ",
	["RP_CHANNELS"] = "Canais RP",
	["RP_CHANNELS_TOOLTIP"] = "Seleccione quais os canais de RP que pretende ver nas suas janelas de chat.",
	["RP_IS_MUTED"] = "RP está trancado.",
	["RP_IS_MUTED_TOOLTIP"] = "Quando o canal RP está trancado, os membros normais da comunidade não podem postar em /rp. Podem continuar a postar em /rp2-9.",
	["RP_WARNING"] = "Avisos de RP",
	["RP_WARNING_TOOLTIP"] = "Similar ao raid warning (/rc), tal é acessível apenas por lideres através de /rpw.",
	["SETTINGS"] = "Configurações.",
	["SETTINGS_TIP"] = "Abrir o interface do painel das opções.",
	["TRAFFIC"] = "Tráfego ",
	["UNKNOWN_SERVER"] = "(Desconhecido)",
	["VERSION_LABEL"] = "Versão: {1}",
	["WEIGHT_UNIT"] = "KG",
	["WHISPER"] = "Sussurrar",
	["WHISPER_TIP"] = "Enviar um sussurro para a facção oposta. (Tal é enviado de forma segura através de uma mensagem direta no Battle-net e não usa a transmissão da comunidade.)"
}

Locales.ruRU = {
	["ADDON_NOTES"] = "Пригласите друзей для кросс-серверной ролевой игры! ",
	["BPS"] = "Б/с",
	["BY_AUTHOR"] = "сделано Tammya-MoonGuard",
	["CONNECT_TO_SERVER_TOOLTIP"] = "Нажмите для того, чтобы присоединиться. ",
	["CROSS_RP"] = "Кросс-серверная ролевая игра"
}

Locales.zhCN = {
	["ADDON_NOTES"] = "将朋友们连接到跨阵营对话！",
	["BPS"] = "B/s",
	["BY_AUTHOR"] = "BY Tammya——月亮守卫",
	["CANT_POST_RPW2"] = "只有团队领袖和助理能发送RP警告。",
	["CONNECT_TO_SERVER_TOOLTIP"] = "点击以连接。",
	["CROSS_RP"] = "Cross RP",
	["CROSSRP_ACTIVE"] = "激活",
	["CROSSRP_INACTIVE"] = "闲置",
	["CROSSRP_NOT_DONE_INITIALIZING"] = "Cross RP还未完成初始化。",
	["ELIXIR_NOTICE"] = "语言药剂将在{1}后失效。",
	["ELIXIR_NOTICE_EXPIRED"] = "语言药剂已失效。",
	["GROUP_LINKED"] = "你加入了一个已连接的团队。",
	["GROUP_STATUS_LINKED"] = "团队已连接",
	["GROUP_UNLINKED"] = "你的团队已断开连接。",
	["HEIGHT_UNIT"] = "英寸",
	["IDLE_TIME"] = "闲置时间",
	["KBPS"] = "kB/s",
	["LANGUAGE_1"] = "兽人语",
	["LANGUAGE_7"] = "通用语",
	["LANGUAGES_NOT_SET"] = "尚未根据你的服务器环境设定语言名称，Cross RP可能不能正常运作。",
	["LATEST_VERSION"] = "最新的版本是{1}。",
	["LINK_GROUP"] = "连接团队",
	["LINK_GROUP_DIALOG"] = "为你的团队输入密码，使用相同密码的团队将被连接。",
	["LINK_GROUP_TOOLTIP"] = "你可以使用这个功能将你的团队和其他团队连接到一起，/rp频道可以在这两个团队间使用。",
	["LINKS"] = "连接",
	["LINKS_TOOLTIP"] = "连接到基于Cross RP的社群。",
	["MAP_TRACKING_CROSSRP_PLAYERS"] = "Cross RP使用者",
	["MINIMAP_TOOLTIP_CLICK_OPEN_MENU"] = "|cffdddddd点击打开菜单。",
	["MINIMAP_TOOLTIP_RIGHTCLICK_OPEN_MENU"] = "|cffdddddd右击打开菜单。",
	["NEEDS_GROUP_LEADER"] = "只有团队领袖可以修改这个。",
	["NEEDS_GROUP_LEADER2"] = "只有团队领袖可以修改这个。",
	["NETWORK_STATUS"] = "网络状态",
	["NO_CONNECTIONS"] = "没有连接。",
	["NO_MORE_ELIXIRS"] = "你的语言药剂耗尽了！",
	["NOT_IN_LINKED_GROUP"] = "你不在一个已连接的团队当中。",
	["OPTION_CHAT_COLORS"] = "聊天颜色",
	["OPTION_MINIMAP_BUTTON"] = "显示小地图按钮",
	["OPTION_MINIMAP_BUTTON_TIP"] = "显示或隐藏小地图按钮（如果你使用TitalPanel、多玩、大脚这类页面插件的话）。",
	["OPTION_TRANSLATE_CHAT_BUBBLES"] = "翻译聊天气泡",
	["OPTION_TRANSLATE_CHAT_BUBBLES_TIP"] = "试图在翻译文本的同时翻译聊天气泡。",
	["OPTION_WHISPER_BUTTON"] = "悄悄话按钮",
	["OPTION_WHISPER_BUTTON_TIP"] = "在已经是战网好友的角色右键菜单中添加 \\\"悄悄话\\\" 按钮，这可能会对魔兽本身的UI造成影响，而且这不是唯一向他们发送悄悄话的方式。",
	["RP_CHANNEL"] = "RP频道",
	["RP_CHANNEL_1_TOOLTIP"] = "主要的RP频道，通过/rp来启用。",
	["RP_CHANNEL_X"] = "RP频道 {1}",
	["RP_CHANNEL_X_TOOLTIP"] = "RP频道2-9是为小范围的RP群组设计的，可以通过/rp#来启用。",
	["RP_CHANNELS"] = "RP频道",
	["RP_CHANNELS_TOOLTIP"] = "选择你希望在聊天框里接收哪些RP频道。",
	["RP_IS_MUTED"] = "RP频道禁言",
	["RP_IS_MUTED_TOOLTIP"] = "RP频道禁言时，玩家不能在/rp发言，但他们仍然可以在/rp2-9当中发言。",
	["RP_WARNING"] = "RP警报",
	["RP_WARNING_TOOLTIP"] = "类似团队警报，由团队领袖通过/rpw来启用。",
	["RPCHAT_NOBRIDGE"] = "无法向{1}发送信息，没有已建立的中继。",
	["RPCHAT_TIMED_OUT"] = "向{1}发送的消息已超时。",
	["SETTINGS"] = "设置",
	["SETTINGS_TIP"] = "打开插件设置面板。",
	["TRAFFIC"] = "流量",
	["TRANSLATE_EMOTES"] = "发送表情动作",
	["TRANSLATE_EMOTES_TIP"] = [=[在靠近敌对阵营角色时将/e转换为/s，对方不需要安装Cross RP。



这在Cross RP闲置状态下没有效果。



避免醉酒。]=],
	["UNKNOWN_SERVER"] = "(未知)",
	["UNLINK_GROUP"] = "断开团队连接。",
	["UNLINK_GROUP_TOOLTIP"] = "将你的团队和其他人的连接断开，禁用/rp频道。",
	["UPDATE_ERROR"] = "Cross RP并未正确安装，如果你最近升级过Cross RP，请关闭并完全重启游戏。如果错误信息持续出现且你确定你在使用最新版Cross RP，请提交一个错误报告。",
	["UPTIME"] = "上行时间",
	["USER_CONNECTED_TO_YOUR_GROUP"] = "{1}连接到了你的团队。",
	["VERSION_LABEL"] = "版本：{1}",
	["VERSION_TOO_OLD"] = "你现有的版本可能无法正确工作并需要升级。请尽快下载Cross RP的最新版本。",
	["WEIGHT_UNIT"] = "磅",
	["WHISPER"] = "悄悄话",
	["WHISPER_TIP"] = "向对方阵营发送悄悄话（该功能使用安全的战网聊天频道，不使用聊天中继频道）。"
}

Locales.zhTW = {
	["ADDON_NOTES"] = "將朋友們連接到跨陣營對話！",
	["BPS"] = "B/s",
	["BY_AUTHOR"] = "BY Tammya——月亮守衛",
	["CANT_POST_RPW2"] = "只有團隊領袖和助理能發送RP警告。",
	["CONNECT_TO_SERVER_TOOLTIP"] = "點擊以連接。",
	["CROSS_RP"] = "Cross RP",
	["CROSSRP_ACTIVE"] = "激活",
	["CROSSRP_INACTIVE"] = "閑置",
	["CROSSRP_NOT_DONE_INITIALIZING"] = "Cross RP還未完成初始化。",
	["ELIXIR_NOTICE"] = "語言藥劑將在{1}後失效。",
	["ELIXIR_NOTICE_EXPIRED"] = "語言藥劑已失效。",
	["GROUP_LINKED"] = "妳加入了壹個已連接的團隊。",
	["GROUP_STATUS_LINKED"] = "團隊已連接",
	["GROUP_UNLINKED"] = "妳的團隊已斷開連接。",
	["HEIGHT_UNIT"] = "英寸",
	["IDLE_TIME"] = "閑置時間",
	["KBPS"] = "kB/s",
	["LANGUAGE_1"] = "獸人語",
	["LANGUAGE_7"] = "通用語",
	["LANGUAGES_NOT_SET"] = "尚未根據妳的服務器環境設定語言名稱，Cross RP可能不能正常運作。",
	["LATEST_VERSION"] = "最新的版本是{1}。",
	["LINK_GROUP"] = "連接團隊",
	["LINK_GROUP_DIALOG"] = "為妳的團隊輸入密碼，使用相同密碼的團隊將被連接。",
	["LINK_GROUP_TOOLTIP"] = "妳可以使用這個功能將妳的團隊和其他團隊連接到壹起，/rp頻道可以在這兩個團隊間使用。",
	["LINKS"] = "連接",
	["LINKS_TOOLTIP"] = "連接到基於Cross RP的社群。",
	["MAP_TRACKING_CROSSRP_PLAYERS"] = "Cross RP使用者",
	["MINIMAP_TOOLTIP_CLICK_OPEN_MENU"] = "|cffdddddd點擊打開菜單。",
	["MINIMAP_TOOLTIP_RIGHTCLICK_OPEN_MENU"] = "|cffdddddd右擊打開菜單。",
	["NEEDS_GROUP_LEADER"] = "只有團隊領袖可以修改這個。",
	["NEEDS_GROUP_LEADER2"] = "只有團隊領袖可以修改這個。",
	["NETWORK_STATUS"] = "網絡狀態",
	["NO_CONNECTIONS"] = "沒有連接。",
	["NO_MORE_ELIXIRS"] = "妳的語言藥劑耗盡了！",
	["NOT_IN_LINKED_GROUP"] = "妳不在壹個已連接的團隊當中。",
	["OPTION_CHAT_COLORS"] = "聊天顏色",
	["OPTION_MINIMAP_BUTTON"] = "顯示小地圖按鈕",
	["OPTION_MINIMAP_BUTTON_TIP"] = "顯示或隱藏小地圖按鈕（如果妳使用TitalPanel、多玩、大腳這類頁面插件的話）。",
	["OPTION_TRANSLATE_CHAT_BUBBLES"] = "翻譯聊天氣泡",
	["OPTION_TRANSLATE_CHAT_BUBBLES_TIP"] = "試圖在翻譯文本的同時翻譯聊天氣泡。",
	["OPTION_WHISPER_BUTTON"] = "悄悄話按鈕",
	["OPTION_WHISPER_BUTTON_TIP"] = "在已經是戰網好友的角色右鍵菜單中添加 \\\"悄悄話\\\" 按鈕，這可能會對魔獸本身的UI造成影響，而且這不是唯壹向他們發送悄悄話的方式。",
	["RP_CHANNEL"] = "RP頻道",
	["RP_CHANNEL_1_TOOLTIP"] = "主要的RP頻道，通過/rp來啟用。",
	["RP_CHANNEL_X"] = "RP頻道 {1}",
	["RP_CHANNEL_X_TOOLTIP"] = "RP頻道2-9是為小範圍的RP群組設計的，可以通過/rp#來啟用。",
	["RP_CHANNELS"] = "RP頻道",
	["RP_CHANNELS_TOOLTIP"] = "選擇妳希望在聊天框裏接收哪些RP頻道。",
	["RP_IS_MUTED"] = "RP頻道禁言",
	["RP_IS_MUTED_TOOLTIP"] = "RP頻道禁言時，玩家不能在/rp發言，但他們仍然可以在/rp2-9當中發言。",
	["RP_WARNING"] = "RP警報",
	["RP_WARNING_TOOLTIP"] = "類似團隊警報，由團隊領袖通過/rpw來啟用。",
	["RPCHAT_NOBRIDGE"] = "無法向{1}發送信息，沒有已建立的中繼。",
	["RPCHAT_TIMED_OUT"] = "向{1}發送的消息已超時。",
	["SETTINGS"] = "設置",
	["SETTINGS_TIP"] = "打開插件設置面板。",
	["TRAFFIC"] = "流量",
	["TRANSLATE_EMOTES"] = "發送表情動作",
	["TRANSLATE_EMOTES_TIP"] = [=[在靠近敵對陣營角色時將/e轉換為/s，對方不需要安裝Cross RP。



這在Cross RP閑置狀態下沒有效果。



避免醉酒。]=],
	["UNKNOWN_SERVER"] = "(未知)",
	["UNLINK_GROUP"] = "斷開團隊連接。",
	["UNLINK_GROUP_TOOLTIP"] = "將妳的團隊和其他人的連接斷開，禁用/rp頻道。",
	["UPDATE_ERROR"] = "Cross RP並未正確安裝，如果妳最近升級過Cross RP，請關閉並完全重啟遊戲。如果錯誤信息持續出現且妳確定妳在使用最新版Cross RP，請提交壹個錯誤報告。",
	["UPTIME"] = "上行時間",
	["USER_CONNECTED_TO_YOUR_GROUP"] = "{1}連接到了妳的團隊。",
	["VERSION_LABEL"] = "版本：{1}",
	["VERSION_TOO_OLD"] = "妳現有的版本可能無法正確工作並需要升級。請盡快下載Cross RP的最新版本。",
	["WEIGHT_UNIT"] = "磅",
	["WHISPER"] = "悄悄話",
	["WHISPER_TIP"] = "向對方陣營發送悄悄話（該功能使用安全的戰網聊天頻道，不使用聊天中繼頻道）。"
}


-------------------------------------------------------------------------------
-- What we do now is take the enUS table, and then merge it with whatever
-- locale the client is using. Just paste it on top, and any untranslated
local locale_strings = Locales.enUS  -- strings will remain English.

do
	local client_locale = GetLocale() -- Gets the WoW locale.
	
	-- Skip this if they're using the English client, or if we don't support
	-- the locale they're using (no strings defined).
	if client_locale ~= "enUS" and Locales[client_locale] then
		if not Locales[client_locale].LANGUAGE_1 
		         or not Locales[client_locale].LANGUAGE_7 then
			-- The languages aren't translated for this locale, warn them...
			Me.languages_not_set = true
		end
		-- Go through the foreign locale strings and overwrite the English
		--  entries. I hate using the word "foreign"; it seems like I'm
		--  treating non-English speakers as aliens, ehe...
		for k, v in pairs( Locales[client_locale] ) do
			locale_strings[k] = v
		end
	end
end

-------------------------------------------------------------------------------
-- Now we've got our merged table, so we can throw away the original data for
Locales = nil -- everything. Just blow up this old Locales table.

-------------------------------------------------------------------------------
-- And here we have the main Locale API. It's simple, but has some cool
Me.Locale = setmetatable( {}, { -- features. Normally, this table will be 
                                  --  stored in a local variable called L.

	-- If we access it like L["KEY"] or L.KEY then it's a direct lookup into
	--  our locale table. If it doesn't exist, then it uses the key directly.
	__index = function( table, key ) -- Most of the translations' keys are
		return locale_strings[key]   --  literal English translations.
		       or key
	end;
	
	-- If we treat the locale table like a function, then we can do 
	--  substitutions, like `L( "string {1}", value )`.
	__call = function( table, key, ... )
		-- First we get the translation. Note this isn't a raw access, so
		key = table[key] -- this goes through the __index metamethod 
		                 -- too if it doesn't exist.
		-- Pack args into a table; iterate over them.
		local args = {...}
		for i = 1, #args do
			-- And replace {1}, {2} etc with them.
			key = key:gsub( "{" .. i .. "}", args[i] )
		end
		return key
	end;
})
